"""

    """

from dataclasses import dataclass
from pathlib import Path

import requests

from .files import read_json_file as rjf


@dataclass
class KeyVal :
    key: str
    val: str

def get_local_toks_js_fp(raw_github_url = 'https://raw.github.com/imahdimir/tok/main/fps.json') :
    rsp = requests.get(raw_github_url)
    js = rsp.json()
    for fp in js.values() :
        if Path(fp).exists() :
            return fp

def get_val_by_key_fr_json(fp , key = None) :
    js = rjf(fp)
    if key is None :
        return KeyVal(key = list(js.keys())[0] , val = list(js.values())[0])
    return KeyVal(key = key , val = js[key])

def get_token(key = None) :
    fp = get_local_toks_js_fp()
    if fp is not None :
        o = get_val_by_key_fr_json(fp , key = key)
        return o.val
    tok = input('Enter token: ')
    return tok



"""

    """

from pathlib import Path


def get_all_subdirs(root_dir) :
    """ returns all subdirectories of the root_dir"""
    return Path(root_dir).glob('**')

def list_all_files_recursively_in_all_subdirs(root_dir) :
    """ lists all files in all subdirectories of the root_dir

    :param root_dir: the root to start the search from
    :return: list of pathes to all files in all subdirectories of the root_dir
    """
    all_subdirs = get_all_subdirs(root_dir)
    all_files = []
    for d in all_subdirs :
        all_files.extend(list(d.glob('*')))
    return all_files

def has_subdir(dirp: Path) :
    for el in dirp.iterdir() :
        if el.is_dir() :
            return True
    return False

def make_dir_if_not_exist(dirr) :
    di = Path(dirr)
    if not di.exists() :
        di.mkdir()
    return di
